---
title: Install TreadI
nav_order: 2
---

<p align="center">
  <img src="{{site.baseurl}}/images/treadi_logo.svg" alt="logo life ring resembling github issue icon" width="256"/>
</p>

Use `pip` to Install [TreadI from the Python Package Index](https://pypi.org/project/TreadI/).

```
pip install TreadI
```

Run TreadI by typing the command `treadi`:

```
$ treadi
```

Next, follow the [Getting Started guide](./getting-started.html).